Prism Docs

Tasks can be either classes or functions.
If tasks live by themselves in a module, the module name is attached to the task name.
Task
Modules can contain multiple task classes and/or functions.
Module with multiple tasks
Directories allow you to organize your code into logical groups.
Darker colors correspond to directories within directories.
Directories allow you to organize your code into logical groups.
Darker colors correspond to additional levels of nesting
Directories allow you to organize your code into logical groups.
Darker colors correspond to additional levels of nesting
Directories allow you to organize your code into logical groups.
Darker colors correspond to additional levels of nesting
Directories within `tasks/`
Click on a node to view its upstream and downstream relationships!
Selected task